#include <stdio.h>
#include <string.h>
#include <math.h>

#include <ft2build.h>
#include FT_FREETYPE_H
#include FT_GLYPH_H

int main( int    argc,
          char** argv )
{
    FT_Library library  = NULL;
    FT_Face    face     = NULL;
    FT_Error   error    = 0;
    FT_Glyph   glyph    = NULL;
    
    FT_Int amajor;
    FT_Int aminor;
    FT_Int apatch;

    char* file_face     = "FreeMono.ttf";

    int   char_size[4];
    char_size[0] = 64;
    char_size[1] = 64;
    char_size[2] = 0;
    char_size[3] = 0;
    
    unsigned long character  = 'a';    
    
    FT_Vector *vector_origin = NULL;
    
    error = FT_Init_FreeType( &library );
    
    if( (error != 0) || (library == NULL) )
    {        
        printf("Cannot initialize a new FreeType library object.\n");
        return 0;
    }
	
    FT_Library_Version( library, &amajor, &aminor, &apatch);
    
    printf("FreeType Version %d.%d.%d\n", amajor, aminor, apatch);
    
    error = FT_New_Face( library, 
                         file_face, 
                         0, 
                         &face );
                         
    if( (error != 0) || (face == NULL) )
    {     
        printf("Cannot create a handle to face object.\n");
        return 0;
    }

    if( FT_IS_SCALABLE(face) )
    {
        error = FT_Set_Char_Size( face, char_size[0], char_size[1], char_size[2], char_size[3] );
    
        if( (error != 0) || (face == NULL) )
        {     
            printf("Cannot set the character dimensions of a given face object.\n");
            return 0;
        }
    }
    
    error = FT_Load_Char( face, character, FT_LOAD_DEFAULT );
    
    if( error != 0 )
    {        
        printf("Cannot load glyph.\n");
        return 0;
    }    
    
    error = FT_Get_Glyph( face->glyph, &glyph );

    if( error != 0 )
    {     
        printf("Cannot extract a glyph image from a slot.\n");
        return 0;
    }

    error = FT_Glyph_To_Bitmap( &glyph,  FT_RENDER_MODE_NORMAL, 0,  1);
                                
    printf("The returned error code is %d\n", error);
    
    if( glyph )
    {
        FT_Done_Glyph ( glyph );
    }

    if( face )
    {
        FT_Done_Face( face );
    }
    
    if( library )
    {
        FT_Done_FreeType( library );
    }
}
 
